@@ -41,8 +41,6 @@
 
 #define KNTLM_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KNTLM_NO_DEPRECATED) && !defined(KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KNTLM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNTLM_NO_DEPRECATED
-#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KNTLM_NO_DEPRECATED_WARNINGS
 #  define KNTLM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNTLM_DEPRECATED_WARNINGS_SINCE KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KNTLM_DEPRECATED
-#  define KNTLM_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KNTLM_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KNTLM_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
